@@ -2,11 +2,10 @@
  * @package     libapache2-vncproxy
  * @file        mod_vncproxy.c
  * @author      Nicholas J. Kisseberth <nkissebe@purdue.edu>
- * @copyright   Copyright (c) 2010-2012 Purdue University. All rights reserved.
+ * @copyright   Copyright (c) 2010-2012 HUBzero Foundation, LLC.
  * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright (c) 2010-2012 Purdue University
- * All rights reserved.
+ * Copyright (c) 2010-2012 HUBzero Foundation, LLC.
  *
  * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
@@ -24,7 +23,7 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * HUBzero is a registered trademark of Purdue University.
+ * HUBzero is a registered trademark of HUBzero Foundation, LLC.
  */
 
 /**
@@ -34,13 +33,11 @@
  *  - possibly close all open file descriptors
  *	  before exec() so we don't have that as
  *    a requirement for the helpers
- *  - remove material from mod_example and mod_proxy_client we don't need
  *  - add encoded hostname mode support (vncsession.host.domain:port)
  *  - add host and port query results to availble helper variables
  *  - triple check apache process lifecycle works right when do the clean
  *    shutdown rather than abrupt exit().
  *  - DBD_PARAMS and DBD_DRIVER should not be required when using helper
- *  - Use /usr/bin/vncproxy helper by default
  *  - Only required configuration (usable) should be vncProxy On
  */
 
@@ -65,8 +62,7 @@ static int vncproxy_connect(request_rec *r, char *token);
 /* We have to peek into the internal apr_socket_t structure
  * to pull out the raw file descriptor so we can pass it
  * to our helper program. I could find no legitimate way
- * to obtain this, there is more to the structure but I only
- * need socketdes.
+ * to obtain this, there is more to this but I only need socketdes.
  */
 struct apr_socket_t
 {
@@ -100,7 +96,7 @@ typedef struct vncproxy_cfg
 	int vncProxyShutdownSSLOnExec;
 } vncproxy_cfg;
 
-static const char *vncproxy_banner = "mod_vncproxy/1.2.0";
+static const char *vncproxy_banner = "mod_vncproxy/1.1.3";
 
 /*
  * Locate our directory configuration record for the current request.
@@ -162,7 +158,6 @@ static const char *cmd_vncProxyDBDParams(cmd_parms *cmd, void *mconfig, const ch
 static const char *cmd_vncProxyHelperStderr(cmd_parms *cmd, void *mconfig, const char *param)
 {
 	vncproxy_cfg *cfg = (vncproxy_cfg *) mconfig;
-	apr_status_t rv;
 
 	if (param && *param) {
 		cfg->vncProxyHelperStderr = param;
@@ -201,7 +196,6 @@ static const char *cmd_vncProxyHelper(cmd_parms *cmd, void *mconfig, const char
 static const char *buildProxyHelperString(apr_pool_t *pool, const char *param, const char *token,
 										  const char *uri, const char *remoteip)
 {
-	vncproxy_cfg *cfg = NULL;
 	char *p, *s, *r;
 
 	ap_log_perror(APLOG_MARK, APLOG_DEBUG, 0, pool, "buildProxyHelperString(%s): start", param);
@@ -316,7 +310,7 @@ static void *vncproxy_create_dir_config(apr_pool_t *p, char *dirspec)
 	cfg->vncProxyHelperStderr = "/var/log/vncproxy/vncproxy.log";
 	cfg->vncProxyDBDriver = "mysql";
 	cfg->vncProxyDBDParams = "";
-	cfg->vncProxyHelper = NULL;
+	cfg->vncProxyHelper = "/usr/bin/vncproxy";
 	cfg->vncProxy = 0;
 	cfg->vncProxyShutdownSSLOnExec = 1;
 
@@ -377,7 +371,7 @@ static void *vncproxy_create_server_config(apr_pool_t *p, server_rec *s)
 	cfg->vncProxyDBDriver = "mysql";
 	cfg->vncProxyDBDParams = "";
 	cfg->vncProxyHelperStderr = "/var/log/vncproxy/vncproxy.log";
-	cfg->vncProxyHelper = NULL;
+	cfg->vncProxyHelper = "/usr/bin/vncproxy";
 	cfg->vncProxy = 0;
 	cfg->vncProxyShutdownSSLOnExec = 1;
 
@@ -443,9 +437,6 @@ static int vncproxy_create_request(request_rec *r)
 	This is currently implemented as a line filter and assume the data we require
 	is all in a single brigade, if it gets called in a non AP_MODE_GETLINE mode it
 	removes itself from the filter list for the remainder of the request.
-
-	This could be rewritten to be mode independent using a small state
-	variable. I'll do this later, but it should work well as written.
  */
 
 static apr_status_t vncproxy_input_filter(ap_filter_t *f, apr_bucket_brigade *bb,
@@ -675,7 +666,7 @@ static int vncproxy_post_read_request(request_rec *r)
 		r->proxyreq = PROXYREQ_PROXY;
 		r->uri = r->unparsed_uri;
 		r->handler = "vncproxy-handler";
-		r->hostname = strdup( r->server->server_hostname );
+		r->hostname = apr_pstrdup( r->pool, r->server->server_hostname );
 		ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "vncproxy_post_read_request(): servername = %s", r->parsed_uri.hostname);
 
 		if ((cfg && cfg->vncProxyShutdownSSLOnExec) ) {
@@ -728,11 +719,10 @@ static int vncproxy_translate_name(request_rec *r)
 	        return DECLINED;
 	}
 
-	if (r->proxyreq) {
-        	/* someone has already set up the proxy, it was possibly ourselves in vncproxy_post_read_request() */
+	if (r->proxyreq) { /* someone has already set up the proxy, it was possibly in vncproxy_post_read_request() */
 		ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "vncproxy_translate_name(): end [ok, vncproxy request detected]");
-        	return OK;
-    	}
+       	return OK;
+    }
 
 	ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "vncproxy_translate_name(): end [declined, vncproxy request not detected]");
 	return DECLINED;
@@ -777,16 +767,24 @@ static int vncproxy_handler(request_rec *r)
 			token = uri.hostname + 11;
 		}
 		else if (r->method_number == M_GET) {
-			char *request = strdup(r->the_request);
+			char *request = apr_pstrdup(r->pool, r->the_request);
 			token = strrchr(request,' ');
-			*token = 0;
-			token = strrchr(request,'/')+1;
+			if (token)
+				*token = 0;
+			token = strrchr(request,'/');
+			if (token && *token)
+				token++;
 		}
 		else
 		{
 			ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "vncproxy_handler(): end [declined, not CONNECT or GET]");
 			return DECLINED;
 		}
+
+		if (*token == '\0' || token == NULL) {
+			ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "vncproxy_handler(): end [connect, failed (no token)]");
+		}
+
 		rv = vncproxy_connect(r,token);
 
 		if (rv == OK) {
